\name{ppc.cv}
\alias{ppc.cv}
\title{ Cross-validation for PPC analysis }
\description{
This function does K-fold cross-validation for PPC analysis 
}
\usage{
ppc.cv(ppc.fit, data, user.parms)
}
\arguments{
  \item{ppc.fit}{ Result of call to ppc.predict }
  \item{data}{List containing mass spec data}
  \item{user.parms}{ List of user defiend parameters}
}
\details{
}
\value{
\item{err}{CV error rate for each threshold value }
\item{se}{se of CV error rate}
\item{confusion}{ Cnfusion matrix for each threshold value}
\item{threshold}{Threshold vlaues used}
\item{yhat}{Predicted values from CV}
\item{prob}{Cv probabilities}
\item{y}{Training set outcome values}
\item{folds}{Indices defining CV folds}
\item{numsites}{Number of m/z sites surviving shrinkage  at each threshold value}
}
\author{ Balasubramanian Narasimhan and Rob Tibshirani }


\examples{
## for a complete worked example of this function in a PPC analysis  see
##  http://www-stat.stanford.edu/~tibs/PPC/Rdist/Rscript.rawdata
}

\keyword{ }% at least one, from doc/KEYWORDS



\eof
\name{ppc.fdr}
\alias{ppc.fdr}
\title{ Function to estimate False Discovery rates for peaks in PPC analysis}
\description{
 Estimate False Discovery rates for peaks in FDR analysis, using permutations
of the sample labels}
}
\usage{
ppc.fdr(data, centroid.fit, peak.fit, split.fit, ppc.fit, user.parms)
}
\arguments{
  \item{data}{ List containing mass spec data}
 \item{centroid.fit}{ Result of call to ppc.make.centroid.list }
  \item{peak.fit}{ Result of call to  ppc.predict.peaks}
  \item{split.fit}{ Result of call to ppc.find.splits}
\item{ppc.fit}{Result of call to  ppc.predict}
  \item{user.parms}{ List  of user defined parameters}
}
\details{
}
\value{
  \item{results}{Matrix with columns- threshold used, number of peaks found, FDR}
  \item{pi0}{Esimate of proportion of truly null peaks}
\item{threshold}{Vector of thresholds used}
}
\author{ Balasubramanian Narasimhan and Rob Tibshirani }


\examples{
## for a complete worked example of this function in a PPC analysis  see
##  http://www-stat.stanford.edu/~tibs/PPC/Rdist/Rscript.rawdata
}

\keyword{ }% at least one, from doc/KEYWORDS



\eof
\name{ppc.find.splits}
\alias{ppc.find.splits}
\title{ Function to find best discriminating split points for training data in mass spec}
\description{
 Find best discriminating split points for training data (to separate the classes).
  Takes centroids.fit- result of call to make.centroids.list
   and peaks.fit- result of call to predict.peaks
}
\usage{
ppc.find.splits(centroid.fit, peak.fit, data, user.parms)
}
\arguments{
  \item{centroid.fit}{ Result of call to ppc.make.centroid.list }
  \item{peak.fit}{  Result of call to  ppc.predict.peaks }
  \item{data}{ List containing mass spec data}
  \item{user.parms}{ List of user defined parameters}
}

\value{
\item{prhat}{Proportion of samples beyond optimal cutpoint  in each outcome class}
\item{pr}{Proportion of samples beyond cutpoints in each outcome class}
\item{n.class}{number of samples in each outcome class}
\item{cutpoints}{Cutpoints (split points) tried}
\item{cuthat}{Optimal cut points}
\item{prclose}{Indicators for split points with prob difference within
  10 percent of that of the optimal split point}
\item{nsplits}{Number of cutpoints tried}
\item{fix.at.one}{Was the optimal cutpoint fixed at one? (i.e no peak vs peak)}
}
\author{ Balasubramanian Narasimhan and Rob Tibshirani }

\examples{
## for a complete worked example of this function in a PPC analysis  see
##  http://www-stat.stanford.edu/~tibs/PPC/Rdist/Rscript.rawdata
}

\keyword{ }% at least one, from doc/KEYWORDS



\eof
\name{ppc-internal}
\title{Internal ppc functions}
\alias{ppc.make.centroids}
\alias{which.is.min}
\alias{medoid}
\alias{permute.rows}
\alias{balanced.folds}
\alias{hclust.1d}
\alias{ppc.read.peaks.file}
\description{Internal ppc functions}
\usage{
ppc.make.centroids(clust.tree, x, user.parms)
which.is.min(x)
medoid(x)
permute.rows(x)
balanced.folds(y, nfolds)
hclust.1d(x, debug=FALSE)
ppc.read.peaks.file(filename)
}
\author{Balasubramanian Narasimhan
 and Rob Tibshirani}
\details{
  These are not to be called by the user.
}
\keyword{internal}


\eof
\name{ppc.make.centroid.list}
\alias{ppc.make.centroid.list}
\title{Function to make a list of peak centroids, from a set of peaks from different spectra}
\description{
This function starts with a list of peaks from a collection of spectra, and does a one
dimensional hierarchical clustering. It  then cuts off the dendogram at height
user.parms\$peak.gap, forming clusters of peaks. The medoids of each cluster form
hte final list of peak centroids.
}
\usage{
ppc.make.centroid.list(data, user.parms)
}
\arguments{
  \item{data}{ List containing mass spc data }
  \item{user.parms}{List of user-defined parameters}
}
\value{
  \item{cent }{Matrix of centroids, one per row}
  \item{peaklist }{Peaklist used}
  \item{clust.tree }{Dendrogram from hclust.1d}
  \item{all.peaks }{Vector of m/z values of all peaks used}
  \item{peak.gap }{Peak width used}
  \item{recluster}{Not currently used}
}
\author{ Balasubramanian Narasimhan and Rob Tibshirani }

\examples{
## for a complete worked example of this function in a PPC analysis  see
##  http://www-stat.stanford.edu/~tibs/PPC/Rdist/Rscript.rawdata
}

\keyword{ }% at least one, from doc/KEYWORDS


\eof
\name{ppc.make.peaklist}
\alias{ppc.make.peaklist}
\title{Function to extract peaks from raw mass spec data }
\description{
This  function to extracts peaks from raw mass spec data. It uses
a very simple peak finder "peaks"- looking  for sites where the intensity is higher than
it is elsewhere in a user-defined window surrounding that site.
}
\usage{
ppc.make.peaklist(data, user.parms)
}
\arguments{
  \item{data}{List containing raw mass spec data}
  \item{user.parms}{ List of user parameters}
}
\value{
List of peaks- one component per spectrum. Each component is a matrix of log m/z values
and peak intensity.
}
\author{ Balasubramanian Narasimhan and Rob Tibshirani }

\examples{
## for a complete worked example of this function in a PPC analysis  see
##  http://www-stat.stanford.edu/~tibs/PPC/Rdist/Rscript.rawdata
}

\keyword{ }% at least one, from doc/KEYWORDS


\eof
\name{ppc.peak.summary}
\alias{ppc.peak.summary}
\title{ Produce summary of peaks from PPC analysis }
\description{
This function produces a summary of peaks from a PPC analysis 
}
\usage{
ppc.peak.summary(centroid.fit, peak.fit, data, user.parms, split.fit)
}
\arguments{
  \item{centroid.fit}{ Result of call to ppc.make.centroid.list }
  \item{peak.fit}{ Result of call to  ppc.predict.peaks}
  \item{data}{ List containing mass spec data}
  \item{user.parms}{ List  of user defined parameters}
  \item{split.fit}{ Result of call to ppc.find.splits}
}
\details{
}
\value{
Matrix containing on row per peak. Columns are peak.position,
                               min, max of peak.position,
                               number.of.spectra in which the peak occurs,
                               rank.of.peak, in discriminatory power,
                               split point for peak height,
 proportion of samples in class 1 exceeding split point, proportion of samples in class 2 exceeding split point  etc,  pairwise differences in these probabilities,
                               peak info for each sample}
}
\author{ Balasubramanian Narasimhan and Rob Tibshirani }

\examples{
## for a complete worked example of this function in a PPC analysis  see
##  http://www-stat.stanford.edu/~tibs/PPC/Rdist/Rscript.rawdata
}

\keyword{ }% at least one, from doc/KEYWORDS



\eof
\name{ppc.peaks}
\alias{ppc.peaks}
\title{Find local maxima}
\description{ Finds the local maxima in a vector.
    This is an R  implementation of the Splus function peaks.
. Note that the span parameter is a proportion between 0 and 1, rather than 
the number of x values (as in the Splus function).
Note also that it only handles a vector as input.
}
\usage{
ppc.peaks(x, span)
}
\arguments{
  \item{x}{ A vector. Peaks will find the local
          maxima in x. }
  \item{span}{A peak is defined as an element in a sequence which is greater
          than all other elements within a window of width length(x)*span centered
          at that element.
  }
}
\details{
 All elements within a halfspan of the end of a sequence or within a
   halfspan of a missing value are FALSE.
}
\value{
vector of logical values, indicating whether there is a peak at each location
}
\author{ Balasubramanian Narasimhan and Rob Tibshirani }

\examples{
x<-rnorm(1000)
a<-ppc.peaks(x, .02)
}

\keyword{ }% at least one, from doc/KEYWORDS



\eof
\name{ppc.plot.hist}
\alias{ppc.plot.hist}
\title{Plot peak histograms from PPC analysis}
\description{
This function plots the  histograms of peaks from a PPC analysis. They are  laid out in order of discriminatory power, starting at the top left and moving down the leftmost column.  At most 25 sites are plotted.
}
\usage{
ppc.plot.hist(peak.fit, ppc.fit, centroid.fit, split.fit, data, first.site = 1, last.site = 25, title.plot = NULL)
}
\arguments{
\item{peak.fit}{ Result of call to  ppc.predict.peaks}
\item{ppc.fit}{ Result of call to  ppc.predict}
 \item{centroid.fit}{ Result of call to ppc.make.centroid.list }
 \item{split.fit}{ Result of call to ppc.find.splits}
  \item{data}{ List containing mass spec data}
  \item{first.site}{ Integer- first site to plot. Default 1}.
  \item{last.site}{Integer- last site to plot. Default 1.}
  \item{title.plot}{Character title for plot. Default NULL}
}
\details{
}
\value{
}
\author{ Balasubramanian Narasimhan and Rob Tibshirani }


\examples{
## for a complete worked example of this function in a PPC analysis  see
##  http://www-stat.stanford.edu/~tibs/PPC/Rscript.rawdata
}

\keyword{ }% at least one, from doc/KEYWORDS

\eof
\name{ppc.plotcv}
\alias{ppc.plotcv}
\title{ Function to plot CV curves from PPC analysis }
\description{
Function to plot CV curves from PPC analysis 
}
\usage{
ppc.plotcv(fit)
}
\arguments{
  \item{fit}{ Result of call to ppc.cv }
}
\details{
}
\value{
}
\author{ Balasubramanian Narasimhan and Rob Tibshirani }


\examples{
## for a complete worked example of this function in a PPC analysis  see
##  http://www-stat.stanford.edu/~tibs/PPC/Rdist/Rscript.rawdata
}

\keyword{ }% at least one, from doc/KEYWORDS



\eof
\name{ppc.plotcvprob}
\alias{ppc.plotcvprob}
\title{ Function to plot CV probabilities from PPC analysis }
\description{
 Function to plot CV probabilities from PPC analysis
}
\usage{
ppc.plotcvprob(fit, data, threshold)
}
\arguments{
  \item{fit}{ Result of call to ppc.cv }
  \item{data}{ List containing mass spec data}
  \item{threshold}{ Value of threshold to use for predictions}
}
\details{
}
\value{
}
\author{ Balasubramanian Narasimhan and Rob Tibshirani }


\examples{
## for a complete worked example of this function in a PPC analysis  see
##  http://www-stat.stanford.edu/~tibs/PPC/Rdist/Rscript.rawdata
}

\keyword{ }% at least one, from doc/KEYWORDS



\eof
\name{ppc.plotfdr}
\alias{ppc.plotfdr}
\title{ Function to plot FDR results from PPC analysis}
\description{
Function to plot FDR results from PPC analysis
}
\usage{
ppc.plotfdr(fdrfit)
}
\arguments{
  \item{fdrfit}{Result of call to ppc.fdr}
}
\details{
}
\value{
}
\author{ Balasubramanian Narasimhan and Rob Tibshirani }


\examples{
## for a complete worked example of this function in a PPC analysis  see
##  http://www-stat.stanford.edu/~tibs/PPC/Rdist/Rscript.rawdata
}

\keyword{ }% at least one, from doc/KEYWORDS



\eof
\name{ppc.predict}
\alias{ppc.predict}
\title{ Function to do test set prediction for the  PPC method}
\description{
This function  does test set prediction for PPC method.
It predicts  outcome classes  for a   list of peaks  from test set spectra.
}
\usage{
ppc.predict(centroid.fit, split.fit, logmz, peaklist.te, n.threshold = 30, threshold = NULL, metric = c("binomial", "euclidean", "absolute"), summ = c("mean", "median"))
}
\arguments{
  \item{centroid.fit}{ Result of a call to ppc.make.centroid.list}
  \item{split.fit}{ Result of a call to ppc.find.splits}
  \item{logmz}{log of m/z values from training data} 
  \item{peaklist.te}{List of peaks from test set-  each component is a matrix of
log m/z values and peak intensities}
  \item{n.threshold}{ Number of shrinkage thresholds to use }
  \item{threshold}{ Threshold values to use}
  \item{metric}{ "binomial","euclidean", or  "absolute"}
  \item{summ}{ "mean" or median"}
}
\value{
  \item{yhat }{Matrix of predicted classes}
  \item{threshold }{Threshold values used.}
  \item{numsites }{Number of  sites surviving the threshold  for each shrinkage value}
  \item{sites }{List of sites surviving the threshold  for each shrinkage value}
  \item{ind }{Indicator matrix of event ( peak intensity at site > cutpoint}
  \item{ind0 }{Indicator matrix of event ( peak intensity at site > cutpoint}
  \item{prob }{Matrix of estimated class probabilities}
  \item{ht }{Matrix of peak intensities}
}
\author{ Balasubramanian Narasimhan and Rob Tibshirani }


\examples{
## for a complete worked example of this function in a PPC analysis  see
##  http://www-stat.stanford.edu/~tibs/PPC/Rdist/Rscript.rawdata
}

\keyword{ }% at least one, from doc/KEYWORDS

\eof
\name{ppc.predict.peaks}
\alias{ppc.predict.peaks}
\title{ A function to find centroid peaks, in a list of individual peaks }
\description{
 Takes centroid.fit (result of a call to make.centroids.list)
  and looks for these m peaks  in peaklist, a list of length n
   returns   ind - an m by n matrix of TRUE/FALSE values
     and ht, the matrix of  corresponding peak heights. A peak
is considered present if it is within user.parms\$peak.gap units from the centroid.
}
\usage{
ppc.predict.peaks(centroid.fit, data)
}

\arguments{
  \item{centroid.fit}{ Result of call to make.centroid.list }
  \item{data}{ List containing the mass spec peaks data }
}

\value{
  \item{ind }{indicator matrix of presence/absence of peak}
  \item{ht }{matrix of  heights. Note: peak is not present if ind=0, even if ht is >0}
}
\author{ Balasubramanian Narasimhan and Rob Tibshirani }


\examples{
## for a complete worked example of this function in a PPC analysis  see
##  http://www-stat.stanford.edu/~tibs/PPC/Rdist/Rscript.rawdata
}

\keyword{ }% at least one, from doc/KEYWORDS



\eof
\name{ppc.predict.peaks1}
\alias{ppc.predict.peaks1}
\title{ A function to find centroid peaks, in a list of individual peaks from one spectrum }
\description{
 Takes centroid.fit (result of a call to make.centroids.list)
  and looks for these m peaks  in a  peaklist from one spectrum.
   returns   ind - an m-vector  of TRUE/FALSE values
     and ht, the vector of  corresponding peak heights. A peak
is considered present if it is within user.parms\$peak.gap units from the centroid.
}
\usage{
ppc.predict.peaks1(centroid.fit, logmz, peaklist.new)
}

\arguments{
  \item{centroid.fit}{ Result of call to make.centroid.list }
  \item{logmz}{Log of m/z values}
\item{ peaklist.new}{Matrix of peaks from a single spectrum. Rows are
(log m/z value, peak intensity)}
}

\value{
  \item{ind }{indicator vector of presence/absence of peak}
  \item{ht }{Vector of  heights. Note: peak is not present if ind=0, even if ht is >0}
}
\author{ Balasubramanian Narasimhan and Rob Tibshirani }


\examples{
## for a complete worked example of this function in a PPC analysis  see
##  http://www-stat.stanford.edu/~tibs/PPC/Rdist/Rscript.rawdata
}

\keyword{ }% at least one, from doc/KEYWORDS



\eof
\name{ppc.predict1}
\alias{ppc.predict1}
\title{ Function to do a   single test set prediction for the  PPC method}
\description{
This function  does test set prediction for PPC method.
It predicts  outcome classes  for a   list of peaks  from a single  test set spectrum.}

\usage{
ppc.predict1(centroid.fit, split.fit, logmz, peaklist.te,  threshold, metric = c("binomial", "euclidean", "absolute"), summ = c("mean", "median"))
}
\arguments{
  \item{centroid.fit}{ Result of a call to ppc.make.centroid.list}
  \item{split.fit}{ Result of a call to ppc.find.splits}
  \item{logmz}{log of m/z values from training data} 
  \item{peaklist.te}{List of peaks from test set-  each component is a matrix of
log m/z values and peak intensities}
  \item{threshold}{ Threshold values to use}
  \item{metric}{ "binomial","euclidean", or  "absolute"}
  \item{summ}{ "mean" or median"}
}
\value{
  \item{yhat }{Matrix of predicted classes}
  \item{threshold }{Threshold values used.}
  \item{numsites }{Number of  sites surviving the threshold  for each shrinkage value}
  \item{sites }{List of sites surviving the threshold  for each shrinkage value}
  \item{ind }{Indicator matrix of event ( peak intensity at site > cutpoint}
  \item{ind0 }{Indicator matrix of event ( peak intensity at site > cutpoint}
  \item{prob }{Matrix of estimated class probabilities}
  \item{ht }{Matrix of peak intensities}
}
\author{ Balasubramanian Narasimhan and Rob Tibshirani }


\examples{
## for a complete worked example of this function in a PPC analysis  see
##  http://www-stat.stanford.edu/~tibs/PPC/Rdist/Rscript.rawdata
}

\keyword{ }% at least one, from doc/KEYWORDS


\eof
\name{ppc.read.peaks.batch}
\alias{ppc.read.peaks.batch}
\title{ Read in mass spec peak data, with batches}
\description{
A function to read in  protein mass spec peaks  data, with  batches
}
\usage{
ppc.read.peaks.batch(dir, batches)
}
\arguments{
  \item{dir}{ Name of directory containing the data }
  \item{batches}{ Vector of batch names }
}
\details{
}
\value{
\item{peaklist}{List of peaks for each sample. Each component is a matrix- one row per m/z site, consiting of log m/z and peak intensity}
\item{filenames}{List of filenames read in}
  \item{logmz}{log m/z values }
}
\author{ Balasubramanian Narasimhan and Rob Tibshirani }


\examples{
## for a complete worked example of this function in a PPC analysis  see
##  http://www-stat.stanford.edu/~tibs/PPC/Rdist/Rscript.peakdata
}

\keyword{ }% at least one, from doc/KEYWORDS

\eof
\name{ppc.read.peaks.nobatch}
\alias{ppc.read.peaks.nobatch}
\title{ Read in mass spec peak data, without batches}
\description{
A function to read in  protein mass spec peaks  data
}
\usage{
ppc.read.peaks.nobatch(dir)
}
\arguments{
  \item{dir}{ Name of directory containing the data }
}
\details{
}
\value{
\item{peaklist}{List of peaks for each sample. Each component is a matrix- one row per m/z site, consiting of log m/z and peak intensity}
\item{filenames}{List of filenames read in}
  \item{logmz}{log m/z values }
}
\author{ Balasubramanian Narasimhan and Rob Tibshirani }


\examples{
## for a complete worked example of this function in a PPC analysis  see
##  http://www-stat.stanford.edu/~tibs/PPC/Rdist/Rscript.peakdata
}

\keyword{ }% at least one, from doc/KEYWORDS

\eof
\name{ppc.read.raw.batch}
\alias{ppc.read.raw.batch}
\title{A function to read in raw protein mass spec data, with  batches }
\description{This function  reads in raw protein mass spec data  from a directory.
The directory is assumed to have on subdirectory per class (eg control or disease).
The subdirectories like "control" have further subdirectories, one per batch.
So the structure looks lik control/batch1/file.csv, control/batch2/file.csv,
disease/batch1/file.csv, etc.
There is one  comma-separated (csv) file.csv in the subdirectory per spectrum,  
having lines of the form m/ value, intensity (one line per m/z site)}
\usage{
ppc.read.raw.batch(dir, batches, mz = NULL)
}
\arguments{
  \item{dir}{ Name of directory containing the data }
  \item{batches}{Vector of character names of batches }
  \item{mz}{Optional vector of m/z values. Default NULL. If NULL, m/z values
are read in from files. Otherwise the  values  in mz are used.
   }
}
\value{
\item{xtr}{Matrix of intensities- one row per m/z site, one col per spectrum}
  \item{mz}{m/z values }
\item{filenames}{List of filenames read in}
}
\author{ Balasubramanian Narasimhan and Rob Tibshirani }


\examples{
## for a complete worked example of this function in a PPC analysis  see
##  http://www-stat.stanford.edu/~tibs/PPC/Rdist/Rscript.rawdata
}

\keyword{ }% at least one, from doc/KEYWORDS

\eof
\name{ppc.read.raw.nobatch}
\alias{ppc.read.raw.nobatch}
\title{A function to read in raw protein mass spec data, with no batches }
\description{This function  reads in raw protein mass spec data  from a directory.
The directory is assumed to have on subdirectory per class (eg control or disease).
There is one  comma-separated (csv) file in the subdirectory per spectrum,  
having lines of the form m/ value, intensity (one line per m/z site)}
\usage{
ppc.read.raw.nobatch(directory, mz = NULL)
}
\arguments{
  \item{directory}{ Name of directory containing the data }
  \item{mz}{Optional vector of m/z values. Default NULL. If NULL, m/z values
are read in from files. Otherwise the  values  in mz are used.}
}
\value{
  \item{xtr}{Matrix of intensities- one row per m/z site, one col per spectrum}
  \item{mz}{m/z values }
\item{filenames}{List of names of  files that were read in}
}
\author{ Balasubramanian Narasimhan and Rob Tibshirani }


\examples{
## for a complete worked example of this function in a PPC analysis  see
##  http://www-stat.stanford.edu/~tibs/PPC/Rdist/Rscript.rawdata
}

\keyword{ }% at least one, from doc/KEYWORDS

\eof
\name{ppc.remove.beforeslash.and.suffix}
\alias{ppc.remove.beforeslash.and.suffix}
\title{ Remove characters efore a slash and at end  }
\description{
This function takes a character file name or vector of character file names,
and removes the character before the rightmost slash, and the suffix after the
last dot. Eg "file/foo/junk.csv" becomes "junk"
}
\usage{
ppc.remove.beforeslash.and.suffix(x)
}
\arguments{
  \item{x}{ Character string or vector of character strings. }
}
\details{
}
\value{
Character string or vector of character strings, modified in the manner descibed
above.
}
\author{ Balasubramanian Narasimhan and Rob Tibshirani }


\examples{
## for a complete worked example of this function in a PPC analysis  see
##  http://www-stat.stanford.edu/~tibs/PPC/Rdist/Rscript.rawdata
}

\keyword{ }% at least one, from doc/KEYWORDS

\eof
\name{ppc.remove.suffix}
\alias{ppc.remove.suffix}
\title{ Function to remove the suffix from a file name }
\description{
This function just removes a .xxx suffix from the end of a filename
 or a vector of filenames
}
\usage{
ppc.remove.suffix(x)
}
\arguments{
  \item{x}{ Filename or vector of filenames }
}
\value{
Filename or list of filenames with suffix removed
}
\author{ Balasubramanian Narasimhan and Rob Tibshirani }
\examples{
## for a complete worked example of this function in a PPC analysis  see
##  http://www-stat.stanford.edu/~tibs/PPC/Rdist/Rscript.rawdata
}
\keyword{}


\eof
\name{ppc.subset.and.reshape}
\alias{ppc.subset.and.reshape}
\title{Function to subset and reshape raw mass spec data }
\description{
This function subsets  raw mass spec data, using the m/z limits mz.min and mz.max in
user.parms. If there are batches, it  also reshapes the data, concatenating the
spectra in different batches for a given patient. Thus for each patient it produces one 
long column of values. The m/z values are strung out as well. Using this trick
we can essentially ignore the  presence of batches for the rest of the analysis,
}
\usage{
ppc.subset.and.reshape(data, user.parms)
}
\arguments{
  \item{data}{ List containing the mass spec data }
  \item{user.parms}{ List of user parameters}
}
\value{
List containing the subset and reshaped mass spec data
}
\author{ Balasubramanian Narasimhan and Rob Tibshirani }


\examples{
## for a complete worked example of this function in a PPC analysis  see
##  http://www-stat.stanford.edu/~tibs/PPC/Rdist/Rscript.rawdata
}

\keyword{ }% at least one, from doc/KEYWORDS


\eof
\name{ppc.subset.and.reshape.peakdata}
\alias{ppc.subset.and.reshape.peakdata}
\title{Function to subset and reshape  mass spec peak data }
\description{
This function subsets   mass spec peak data, using the m/z limits mz.min and mz.max in
user.parms. If there are batches, it  also reshapes the data, concatenating the
spectra in different batches for a given patient. Thus for each patient it produces one 
long vector of values. The m/z values are strung out as well. Using this trick
we can essentially ignore the  presence of batches for the rest of the analysis,
}
\usage{
ppc.subset.and.reshape.peakdata(data, user.parms)
}
\arguments{
  \item{data}{ List containing the mass spec data }
  \item{user.parms}{ List of user parameters}
}
\value{
List containing the subset and reshaped mass spec data
}
\author{ Balasubramanian Narasimhan and Rob Tibshirani }


\examples{
## for a complete worked example of this function in a PPC analysis  see
##  http://www-stat.stanford.edu/~tibs/PPC/Rdist/Rscript.peakdata
}

\keyword{ }% at least one, from doc/KEYWORDS


\eof
